''
'' P2-ES Accessory Set control board driver
''

'' methods:
''
'' start(base)
''   initialize the object; base is where the board is plugged in
'' setled(pin, state)
''   pin must be 0-3; sets corresponding LED to off (state=0) or on (state<>0)
'' getbutton(pin)
''   pin must be 0-3: reads the state of the corresponding button
''   note that we remap so that the LEDs match the buttons
''   0 -> 5, 1 -> 4, 2 -> 7, 3 -> 6

' the base pin for the board
dim basepin as integer

' the button map
' we make this "dim shared" because the same map may be shared by
' all instances of the object

dim shared as integer buttonmap(3) = { 5, 4, 6, 7 }

const pbmode = 0b0000_000_111_010_00_00000_0

' start
sub start(pin as integer)
  basepin = pin
  
  ' set up the input pins
  ' set PB pin mode, high = float, low = 15k-ohm
  for i = 4 to 7
     wrpin(basepin+i, pbmode)
     pinlo(basepin+i)
  next i
end sub

' turn an led off (state = 0) or on (state = 1)
sub setled(pin as integer, state as integer)
  ' pin should be between 0 and 3; we guarantee this by
  ' taking only the bottom two bits (AND with 0b11)
  pin = (pin and 0b11)
  ' now add in the base for the board
  pin = pin + basepin

  ' now set it high or low, as needed
  if state = 0 then
    pinl(pin)
  else
    pinh(pin)
  end if
end sub

' read button 0-3
function getbutton(pin as integer) as integer
  ' isolate to 0-3
  pin = pin and 3
  ' remap and adjust to proper base
  pin = basepin + buttonmap(pin)

  ' drive the button low
  pinlo(pin)

  ' now read it
  return pinr(pin)
end function

'
' test program; just loops and turns LED on according to button
'
' this code is in the "program" method, which will generally be removed
' if the file is used as an object
'
var i = 0
var b = 0

start(8)  ' adjust depending on where your board is plugged in

do
  for i = 0 to 3
    b = getbutton(i)
    setled(i, b)
  next i
loop
